==> telephone-sqlserver-3.0.20.jar: filiale/furuike/sqls/serviceDetails.sql <==
SELECT
    *,
    case when f_again_revisit ='否' then '已回访'
         when ISNULL(f_phone2, '') = '' then '无法操作'
         else '待回访' end f_return_status
FROM (
         SELECT
             tswo.*,
             tsw.f_date,
             tsw.f_name,
             tsw.f_date_come,
             tsw.f_date_leave,
             tsw.f_signname,
             tsw.f_sign_imgid,
             tsw.f_result_status,
             tsw.f_service_idea,
             tsw.f_remarks as f_remarkss,
             sa.defname,
             sa.sender,
             CASE
                 WHEN tswo.f_workorder_type != '报修单' THEN -1
                 WHEN tsw.f_result_status = '已完成' THEN -1
                 WHEN tswo.f_finish_date = '' THEN -1
                 WHEN DATEDIFF( DAY, tswo.f_finish_date, GETDATE( ) ) < 0 THEN -1
                 ELSE DATEDIFF( DAY, tswo.f_finish_date, GETDATE( ) )
                 END overday,
             case when ISNULL(tswo.f_phone, '') != '' then tswo.f_phone else tu.f_user_phone end f_phone2
         FROM
             t_serviceworkorder tswo
                 LEFT JOIN ( SELECT * FROM t_servicework sw WHERE sw.id = ( SELECT MAX ( id ) FROM t_servicework WHERE serviceid = sw.serviceid ) ) tsw ON tswo.id= tsw.serviceid
                 LEFT JOIN ( SELECT * FROM ACTIVITYINS act WHERE act.id = ( SELECT MAX ( id ) FROM ACTIVITYINS WHERE PROCESSID = act.PROCESSID ) ) SA ON tswo.F_PROCESSID = sa.PROCESSID
                 LEFT JOIN AFproduct.dbo.t_userinfo tu on tswo.f_userinfo_id = tu.f_userinfo_id
     ) t
WHERE
    {condition}
ORDER BY
    f_created_date DESC

==> telephone-sqlserver-3.0.68.jar: filiale/furuike/sqls/serviceDetails.sql <==
SELECT
    *,
    case when f_again_revisit ='否' then '已回访'
         when ISNULL(f_phone2, '') = '' then '无法操作'
         else '待回访' end f_return_status
FROM (
         SELECT
             tswo.*,
             tsw.f_date,
             tsw.f_name,
             tsw.f_date_come,
             tsw.f_date_leave,
             tsw.f_signname,
             tsw.f_sign_imgid,
             tsw.f_result_status,
             tsw.f_service_idea,
             tsw.f_remarks as f_remarkss,
             sa.defname,
             sa.sender,
             CASE
                 WHEN tswo.f_workorder_type != '报修单' THEN -1
                 WHEN tsw.f_result_status = '已完成' THEN DATEDIFF( SECOND, tswo.f_finish_date, tsw.f_date )
                 WHEN tswo.f_finish_date = '' THEN -1
                 WHEN DATEDIFF( SECOND, tswo.f_finish_date, GETDATE( ) ) < 0 THEN -1
                 ELSE DATEDIFF( SECOND, tswo.f_finish_date, GETDATE( ) )
                 END overday,
             case when ISNULL(tswo.f_phone, '') != '' then tswo.f_phone else isnull(tu.f_user_phone,'') end f_phone2
         FROM
             t_serviceworkorder tswo
                 LEFT JOIN ( SELECT * FROM t_servicework sw WHERE sw.id = ( SELECT MAX ( id ) FROM t_servicework WHERE serviceid = sw.serviceid ) ) tsw ON tswo.id= tsw.serviceid
                 LEFT JOIN ( SELECT * FROM ACTIVITYINS act WHERE act.id = ( SELECT MAX ( id ) FROM ACTIVITYINS WHERE PROCESSID = act.PROCESSID ) ) SA ON tswo.F_PROCESSID = sa.PROCESSID
                 LEFT JOIN AFproduct.dbo.t_userinfo tu on tswo.f_userinfo_id = tu.f_userinfo_id
     ) t
WHERE
    {condition}
ORDER BY
    f_created_date DESC
